==> aksharamukha-1.0.12.tar.gz: aksharamukha-1.0.12/aksharamukha/ScriptMap/MainIndic/Saurashtra.py <==
# -*- coding: utf-8 -*-

# Script Mapping for Devanagari

VowelMap =  [
            '\uA882',
            '\uA883',
            '\uA884',
            '\uA885',
            '\uA886',
            '\uA887',
            '\uA888',
            '\uA889',
            '\uA88A',
            '\uA88B',
            '\uA88D',
            '\uA88E',
            '\uA890',
            '\uA891',
            ]

SouthVowelMap = [
                '\uA88C',
                '\uA88F',
                ]

ModernVowelMap = [
                 '\uA88C\u02BC',
                 '\uA883\u02BC',
                 ]

SinhalaVowelMap = [
                  '\uA88C\u02C7'
                  ]
    
VowelSignMap =  [
                '\uA8B5',
                '\uA8B6',
                '\uA8B7',
                '\uA8B8',
                '\uA8B9',
                '\uA8BA',
                '\uA8BB',
                '\uA8BC',
                '\uA8BD',
                '\uA8BF',
                '\uA8C0',
                '\uA8C2',
                '\uA8C3',
                ]

SouthVowelSignMap = [
                    '\uA8BE',
                    '\uA8C1',
                    ]

ModernVowelSignMap =[
                    '\uA8BE\u02BC',
                    '\uA8B5\u02BC']

SinhalaVowelSignMap = [
                      '\uA8BF\u02C7'
                      ]

AyogavahaMap = [
               '\uA8C5',
               '\uA880',
               '\uA881'
               ]
    
ViramaMap =  [
             '\uA8C4'
             ]

ConsonantMap =  [
                '\uA892',
                '\uA893',
                '\uA894',
                '\uA895',
                '\uA896',
                
                '\uA897',
                '\uA898',
                '\uA899',
                '\uA89A',
                '\uA89B',
                
                '\uA89C',
                '\uA89D',
                '\uA89E',
                '\uA89F',
                '\uA8A0',
                
                '\uA8A1',
                '\uA8A2',
                '\uA8A3',
                '\uA8A4',
                '\uA8A5',
                
                '\uA8A6',
                '\uA8A7',
                '\uA8A8',
                '\uA8A9',
                '\uA8AA',
                
                '\uA8AB',
                '\uA8AC',
                '\uA8AD',
                '\uA8AE',
                
                '\uA8AF',
                '\uA8B0',
                '\uA8B1',
                '\uA8B2'
                ]

SouthConsonantMap = [
                    '\uA8B3',
                    '\uA8B3\u00B7',
                    '\uA8AC\u00B7',
                    '\uA8A5\u00B7'
                    ]

NuktaConsonantMap =  [
                     '\uA892\u00B7',
                     '\uA893\u00B7',
                     '\uA894\u00B7',
                     '\uA899\u00B7',
                     '\uA89E\u00B7',
                     '\uA89F\u00B7',
                     '\uA8A7\u00B7',
                     '\uA8AB\u00B7'
                     ]

SinhalaConsonantMap =[
                     '\uA880\u02C6\uA894',
                     '\uA880\u02C6\uA899',
                     '\uA880\u02C6\uA89E',
                     '\uA880\u02C6\uA8A3',
                     '\uA880\u02C6\uA8A8',
                      ]

NuktaMap = [
           '\u00B7'
           ]
    
OmMap = [
        '\uA890\uA880'
        ]

SignMap =[
         '\u0C3D',
         '\uA8CE',
         '\uA8CF'
         ]

Aytham =[AyogavahaMap[2]+'\u02BC']


NumeralMap = [
             '\uA8D0',
             '\uA8D1',
             '\uA8D2',
             '\uA8D3',
             '\uA8D4',
             '\uA8D5',
             '\uA8D6',
             '\uA8D7',
             '\uA8D8',
             '\uA8D9'
             ]

==> aksharamukha-1.7.tar.gz: aksharamukha-1.7/aksharamukha/ScriptMap/MainIndic/Saurashtra.py <==
# -*- coding: utf-8 -*-

# Script Mapping for Devanagari

VowelMap =  [
            '\uA882',
            '\uA883',
            '\uA884',
            '\uA885',
            '\uA886',
            '\uA887',
            '\uA888',
            '\uA889',
            '\uA88A',
            '\uA88B',
            '\uA88D',
            '\uA88E',
            '\uA890',
            '\uA891',
            ]

SouthVowelMap = [
                '\uA88C',
                '\uA88F',
                ]

ModernVowelMap = [
                 '\uA88C\u02BD',
                 '\uA883\u02BD',
                 ]

SinhalaVowelMap = [
                  '\uA88C\u02BD'
                  ]

VowelSignMap =  [
                '\uA8B5',
                '\uA8B6',
                '\uA8B7',
                '\uA8B8',
                '\uA8B9',
                '\uA8BA',
                '\uA8BB',
                '\uA8BC',
                '\uA8BD',
                '\uA8BF',
                '\uA8C0',
                '\uA8C2',
                '\uA8C3',
                ]

SouthVowelSignMap = [
                    '\uA8BE',
                    '\uA8C1',
                    ]

ModernVowelSignMap =[
                    '\uA8BE\u02BD',
                    '\uA8B5\u02BD']

SinhalaVowelSignMap = [
                      '\uA8BF\u02BD'
                      ]

AyogavahaMap = [
               '\uA8C5',
               '\uA880',
               '\uA881'
               ]

ViramaMap =  [
             '\uA8C4'
             ]

ConsonantMap =  [
                '\uA892',
                '\uA893',
                '\uA894',
                '\uA895',
                '\uA896',

                '\uA897',
                '\uA898',
                '\uA899',
                '\uA89A',
                '\uA89B',

                '\uA89C',
                '\uA89D',
                '\uA89E',
                '\uA89F',
                '\uA8A0',

                '\uA8A1',
                '\uA8A2',
                '\uA8A3',
                '\uA8A4',
                '\uA8A5',

                '\uA8A6',
                '\uA8A7',
                '\uA8A8',
                '\uA8A9',
                '\uA8AA',

                '\uA8AB',
                '\uA8AC',
                '\uA8AD',
                '\uA8AE',

                '\uA8AF',
                '\uA8B0',
                '\uA8B1',
                '\uA8B2'
                ]

SouthConsonantMap = [
                    '\uA8B3',
                    '\uA8B3\u02BD',
                    '\uA8AC\u02BD',
                    '\uA8A5\u02BD'
                    ]

NuktaConsonantMap =  [
                     '\uA892\u02BD',
                     '\uA893\u02BD',
                     '\uA894\u02BD',
                     '\uA899\u02BD',
                     '\uA89E\u02BD',
                     '\uA89F\u02BD',
                     '\uA8A7\u02BD',
                     '\uA8AB\u02BD'
                     ]

SinhalaConsonantMap =[
                     '\uA880\u02BD\uA894',
                     '\uA880\u02BD\uA899',
                     '\uA880\u02BD\uA89E',
                     '\uA880\u02BD\uA8A3',
                     '\uA880\u02BD\uA8A8',
                      ]

NuktaMap = [
           '\u02BD'
           ]

OmMap = [
        '\uA890\uA880'
        ]

SignMap =[
         '\u0C3D',
         '\uA8CE',
         '\uA8CF'
         ]

Aytham =[AyogavahaMap[2]+'\u02BC']


NumeralMap = [
             '\uA8D0',
             '\uA8D1',
             '\uA8D2',
             '\uA8D3',
             '\uA8D4',
             '\uA8D5',
             '\uA8D6',
             '\uA8D7',
             '\uA8D8',
             '\uA8D9'
             ]
